@@ -47,4 +47,10 @@ class Component:
         return self.styles.get('cvc-template-type')
 
     def get_template_name(self):
-        return self.styles.get('cvc-template-name')
\ No newline at end of file
+        return self.styles.get('cvc-template-name')
+
+    def get_lib_version(self):
+        return self.styles.get('cvc-lib-version')
+    
+    def get_component_status(self):
+        return self.styles.get('cvc-component-status')
\ No newline at end of file
